****************************
Mopidy-Transistor
****************************

.. image:: https://img.shields.io/pypi/v/Mopidy-Transistor.svg?style=flat
    :target: https://pypi.python.org/pypi/Mopidy-Transistor/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/travis/lukhe/mopidy-transistor/master.svg?style=flat
    :target: https://travis-ci.org/lukhe/mopidy-transistor
    :alt: Travis CI build status

.. image:: https://img.shields.io/coveralls/lukhe/mopidy-transistor/master.svg?style=flat
   :target: https://coveralls.io/r/lukhe/mopidy-transistor
   :alt: Test coverage

Mopidy Extension for Transistor project


Installation
============

Install by running::

    pip install Mopidy-Transistor

Or, if available, install the Debian/Ubuntu package from `apt.mopidy.com <http://apt.mopidy.com/>`_.


Configuration
=============

Before starting Mopidy, you must add configuration for
Mopidy-Transistor to your Mopidy configuration file::

    [transistor]
    # TODO: Add example of extension config


Project resources
=================

- `Source code <https://github.com/lukhe/mopidy-transistor>`_
- `Issue tracker <https://github.com/lukhe/mopidy-transistor/issues>`_


Credits
=======

- Original author: `Vivien HENRY <https://github.com/lukh>`_
- Current maintainer: `Vivien HENRY <https://github.com/lukh>`_
- `Contributors <https://github.com/lukhe/mopidy-transistor/graphs/contributors>`_


Changelog
=========

v0.0.1 (UNRELEASED)
----------------------------------------

- Initial release.
